@@ -47,16 +47,22 @@ SESSION_REDIS_CONNECTION_POOL = getattr(
     None
 )
 
+SESSION_REDIS_JSON_ENCODING = getattr(
+    settings,
+    'SESSION_REDIS_JSON_ENCODING',
+    'latin-1'
+)
+
 if SESSION_REDIS_URL is None:
     # redis clouds ENV variables
     SESSION_REDIS_ENV_URLS = getattr(
         settings,
         'SESSION_REDIS_ENV_URLS', (
+            'REDISCLOUD_URL'
             'REDISTOGO_URL',
             'OPENREDIS_URL',
             'REDISGREEN_URL',
             'MYREDIS_URL',
-            'REDISCLOUD_URL'
         )
     )
 
